@@ -1,8 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2019 Intel Corporation. All rights reserved.
- * All rights reserved.
+ * Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -36,7 +35,7 @@
 #include <sys/stat.h>
 
 #include "pqos.h"
-
+#include "allocation.h"
 #include "common.h"
 #include "os_cap.h"
 #include "types.h"
@@ -45,126 +44,12 @@
 #include "resctrl_alloc.h"
 #include "perf_monitoring.h"
 
-#define PROC_CPUINFO "/proc/cpuinfo"
+#define PROC_CPUINFO     "/proc/cpuinfo"
 #define PROC_FILESYSTEMS "/proc/filesystems"
-#define PROC_MOUNTS "/proc/mounts"
+#define PROC_MOUNTS      "/proc/mounts"
 
 static int mba_ctrl = -1; /**< mba ctrl support */
 
-/**
- * @brief Checks file fname to detect str and sets a flag
- *
- * @param [in] fname name of the file to be searched
- * @param [in] str string being searched for
- * @param [in] check_symlink a flag indicating if a path must be checked
- *             against symlinks
- * @param [out] supported pointer to os_supported flag
- *
- * @return Operation status
- * @retval PQOS_RETVAL_OK success
- */
-static int
-detect_os_support(const char *fname, const char *str, int check_symlink,
-                  int *supported)
-{
-        FILE *fd;
-        char temp[1024];
-
-        if (fname == NULL || str == NULL || supported == NULL)
-                return PQOS_RETVAL_PARAM;
-
-        if (check_symlink)
-                fd = fopen_check_symlink(fname, "r");
-        else
-                fd = fopen(fname, "r");
-
-        if (fd == NULL) {
-                LOG_DEBUG("%s not found.\n", fname);
-                *supported = 0;
-                return PQOS_RETVAL_OK;
-        }
-
-        while (fgets(temp, sizeof(temp), fd) != NULL) {
-                if (strstr(temp, str) != NULL) {
-                        *supported = 1;
-                        fclose(fd);
-                        return PQOS_RETVAL_OK;
-                }
-        }
-
-        fclose(fd);
-        return PQOS_RETVAL_OK;
-}
-
-/**
- * @brief Read uint64 from file
- *
- * @param [in] fname name of the file
- * @param [in] base numerical base
- * @param [out] value UINT value
- *
- * @return Operation status
- * @retval PQOS_RETVAL_OK success
- */
-static int
-readuint64(const char *fname, unsigned base, uint64_t *value)
-{
-        FILE *fd;
-        char buf[16] = "\0";
-        char *s = buf;
-        char *endptr = NULL;
-        size_t bytes;
-
-        ASSERT(fname != NULL);
-        ASSERT(value != NULL);
-
-        fd = fopen_check_symlink(fname, "r");
-        if (fd == NULL)
-                return PQOS_RETVAL_ERROR;
-
-        bytes = fread(buf, sizeof(buf) - 1, 1, fd);
-        if (bytes == 0 && !feof(fd)) {
-                fclose(fd);
-                return PQOS_RETVAL_ERROR;
-        }
-        fclose(fd);
-
-        *value = strtoull(s, &endptr, base);
-
-        if (!((*s != '\0' && *s != '\n') &&
-                (*endptr == '\0' || *endptr == '\n'))) {
-                LOG_ERROR("Error converting '%s' to unsigned number!\n", buf);
-                return PQOS_RETVAL_ERROR;
-        }
-
-        return PQOS_RETVAL_OK;
-}
-
-/**
- * @brief Retrieves number of closids
- *
- * @param [in] dir path to info directory
- * @param [out] num_closids place to store retrieved value
- *
- * @return Operation status
- * @retval PQOS_RETVAL_OK on success
- */
-static int
-get_num_closids(const char *dir, unsigned *num_closids)
-{
-        char path[128];
-        int ret;
-        uint64_t val;
-
-        snprintf(path, sizeof(path) - 1, "%s/num_closids", dir);
-
-        ret = readuint64(path, 10, &val);
-        if (ret == PQOS_RETVAL_OK)
-                *num_closids = val;
-
-        return ret;
-}
-
 /**
  * @brief Retrieves number of ways
  *
@@ -183,16 +68,20 @@ get_num_ways(const char *dir, unsigned *num_ways)
 
         snprintf(path, sizeof(path) - 1, "%s/cbm_mask", dir);
 
-        ret = readuint64(path, 16, &val);
-        if (ret == PQOS_RETVAL_OK) {
+        ret = pqos_fread_uint64(path, 16, &val);
+        if (ret != PQOS_RETVAL_OK)
+                return ret;
+
+        if (val > 0 && val <= UINT64_MAX) {
                 *num_ways = 0;
                 while (val > 0) {
                         (*num_ways)++;
                         val = val >> 1;
                 }
+                return PQOS_RETVAL_OK;
         }
 
-        return ret;
+        return PQOS_RETVAL_ERROR;
 }
 
 /**
@@ -214,14 +103,15 @@ get_shareable_bits(const char *dir, uint64_t *shareable_bits)
         snprintf(path, sizeof(path) - 1, "%s/shareable_bits", dir);
 
         /* Information not present in info dir */
-        if (access(path, F_OK) != 0) {
+        if (!pqos_file_exists(path)) {
                 LOG_DEBUG("Unable to obtain ways contention bit-mask, %s file "
-                         "does not exist\n", path);
+                          "does not exist\n",
+                          path);
                 *shareable_bits = 0;
                 return PQOS_RETVAL_OK;
         }
 
-        return readuint64(path, 16, shareable_bits);
+        return pqos_fread_uint64(path, 16, shareable_bits);
 }
 
 int
@@ -229,20 +119,18 @@ os_cap_init(const enum pqos_interface inter)
 {
         int ret;
         int res_flag = 0;
-        struct stat st;
 
         /**
          * resctrl detection
          */
-        ret = detect_os_support(PROC_FILESYSTEMS, "resctrl", 0, &res_flag);
+        ret = pqos_file_contains(PROC_FILESYSTEMS, "resctrl", &res_flag);
         if (ret != PQOS_RETVAL_OK) {
                 LOG_ERROR("Fatal error encountered in resctrl detection!\n");
                 return ret;
         }
-        LOG_INFO("%s\n", res_flag ?
-                 "resctrl detected" :
-                 "resctrl not detected. "
-                 "Kernel version 4.10 or higher required");
+        LOG_INFO("%s\n", res_flag ? "resctrl detected"
+                                  : "resctrl not detected. "
+                                    "Kernel version 4.10 or higher required");
 
         if (res_flag == 0) {
                 LOG_ERROR("OS interface selected but not supported\n");
@@ -252,7 +140,7 @@ os_cap_init(const enum pqos_interface inter)
         /**
          * Mount resctrl with default parameters
          */
-        if (access(RESCTRL_PATH"/cpus", F_OK) != 0) {
+        if (!pqos_file_exists(RESCTRL_PATH "/cpus")) {
                 LOG_INFO("resctrl not mounted\n");
                 /**
                  * Check if it is possible to enable MBA CTRL
@@ -284,7 +172,7 @@ os_cap_init(const enum pqos_interface inter)
         }
 
         if (inter == PQOS_INTER_OS_RESCTRL_MON &&
-            stat(RESCTRL_PATH_INFO_L3_MON, &st) != 0) {
+            !pqos_dir_exists(RESCTRL_PATH_INFO_L3_MON)) {
                 LOG_ERROR("Resctrl monitoring selected but not supported\n");
                 return PQOS_RETVAL_INTER;
         }
@@ -292,22 +180,11 @@ os_cap_init(const enum pqos_interface inter)
         return ret;
 }
 
-/**
- * @brief Checks if event is supported by resctrl monitoring
- *
- * @param [in] event monitoring event type
- * @param [out] supported set to 1 if resctrl support is present
- * @param [out] scale scale factor
- *
- * @return Operation status
- * @retval PQOS_RETVAL_OK success
- */
-static int
-detect_mon_resctrl_support(const enum pqos_mon_event event,
+int
+os_cap_mon_resctrl_support(const enum pqos_mon_event event,
                            int *supported,
                            uint32_t *scale)
 {
-        struct stat st;
         const char *event_name = NULL;
         int ret;
 
@@ -316,7 +193,7 @@ detect_mon_resctrl_support(const enum pqos_mon_event event,
         *supported = 0;
 
         /* resctrl monitoring is not supported */
-        if (stat(RESCTRL_PATH_INFO_L3_MON, &st) != 0)
+        if (!pqos_dir_exists(RESCTRL_PATH_INFO_L3_MON))
                 return PQOS_RETVAL_OK;
 
         switch (event) {
@@ -334,8 +211,8 @@ detect_mon_resctrl_support(const enum pqos_mon_event event,
                 break;
         }
 
-        ret = detect_os_support(RESCTRL_PATH_INFO_L3_MON"/mon_features",
-                                 event_name, 1, supported);
+        ret = pqos_file_contains(RESCTRL_PATH_INFO_L3_MON "/mon_features",
+                                 event_name, supported);
 
         if (scale != NULL)
                 *scale = 1;
@@ -343,7 +220,6 @@ detect_mon_resctrl_support(const enum pqos_mon_event event,
         return ret;
 }
 
-
 /**
  * @brief Reads scale factor of perf monitoring event
  *
@@ -362,79 +238,71 @@ get_mon_perf_scale_factor(const char *event_name, uint32_t *scale)
         unsigned unit = 1;
         int ret;
         FILE *fd;
+        int result = PQOS_RETVAL_OK;
 
         ASSERT(scale != NULL);
         ASSERT(event_name != NULL);
 
         /* read scale factor value */
-        snprintf(path, sizeof(path) - 1, PERF_MON_PATH"/events/%s.scale",
+        snprintf(path, sizeof(path) - 1, PERF_MON_PATH "/events/%s.scale",
                  event_name);
 
-        fd = fopen_check_symlink(path, "r");
+        fd = pqos_fopen(path, "r");
         if (fd == NULL) {
                 LOG_ERROR("Failed to open %s perf monitoring event scale "
-                          "file!\n", event_name);
+                          "file!\n",
+                          event_name);
                 return PQOS_RETVAL_ERROR;
         }
         ret = fscanf(fd, "%10lf", &scale_factor);
         fclose(fd);
-        if (ret < 1) {
+        if (ret < 1 || scale_factor <= 0.0) {
                 LOG_ERROR("Failed to read %s perf monitoring event scale "
-                          "factor!\n", event_name);
+                          "factor!\n",
+                          event_name);
                 return PQOS_RETVAL_ERROR;
         }
 
         /* read scale factor unit */
-        snprintf(path, sizeof(path) - 1, PERF_MON_PATH"/events/%s.unit",
+        snprintf(path, sizeof(path) - 1, PERF_MON_PATH "/events/%s.unit",
                  event_name);
 
-        fd = fopen_check_symlink(path, "r");
+        fd = pqos_fopen(path, "r");
         if (fd == NULL) {
                 LOG_ERROR("Failed to open %s perf monitoring event unit "
-                          "file!\n", event_name);
+                          "file!\n",
+                          event_name);
                 return PQOS_RETVAL_ERROR;
         }
 
-        if (fgets(buf, sizeof(buf), fd) != NULL) {
+        if (pqos_fgets(buf, sizeof(buf), fd) != NULL) {
                 if (strncmp(buf, "Bytes", sizeof(buf)) == 0)
                         unit = 1;
                 else if (strncmp(buf, "MB", sizeof(buf)) == 0)
                         unit = 1000000;
                 else {
                         LOG_ERROR("Unknown \"%s\" scale factor unit", buf);
-                        fclose(fd);
-                        return PQOS_RETVAL_ERROR;
+                        result = PQOS_RETVAL_ERROR;
                 }
         } else {
                 LOG_ERROR("Failed to read %s perf monitoring event unit!\n",
                           event_name);
-                fclose(fd);
-                return PQOS_RETVAL_ERROR;
+                result = PQOS_RETVAL_ERROR;
         }
         fclose(fd);
 
-        *scale = (uint32_t)(scale_factor * unit);
+        if (result == PQOS_RETVAL_OK)
+                *scale = (uint32_t)(scale_factor * unit);
 
         return PQOS_RETVAL_OK;
 }
 
-/**
- * @brief Checks if event is supported by perf
- *
- * @param [in] event monitoring event type
- * @param [out] supported set to 1 if perf support is present
- * @param [out] scale scale factor
- *
- * @return Operation status
- * @retval PQOS_RETVAL_OK success
- */
-static int
-detect_mon_perf_support(const enum pqos_mon_event event,
+int
+os_cap_mon_perf_support(const enum pqos_mon_event event,
                         int *supported,
                         uint32_t *scale)
 {
         char path[128];
-        struct stat st;
         const char *event_name = NULL;
         int ret;
         static int warn = 1;
@@ -467,8 +335,9 @@ detect_mon_perf_support(const enum pqos_mon_event event,
                 break;
         }
 
-        snprintf(path, sizeof(path) - 1, PERF_MON_PATH"/events/%s", event_name);
-        if (stat(path, &st) != 0)
+        snprintf(path, sizeof(path) - 1, PERF_MON_PATH "/events/%s",
+                 event_name);
+        if (!pqos_file_exists(path))
                 return PQOS_RETVAL_OK;
 
         *supported = 1;
@@ -522,7 +391,7 @@ detect_mon_support(const enum pqos_mon_event event,
                 return PQOS_RETVAL_OK;
         }
 
-        ret = detect_mon_resctrl_support(event, supported, scale);
+        ret = os_cap_mon_resctrl_support(event, supported, scale);
         if (ret != PQOS_RETVAL_OK) {
                 LOG_ERROR("Fatal error encountered while checking for resctrl "
                           "monitoring support\n");
@@ -531,7 +400,7 @@ detect_mon_support(const enum pqos_mon_event event,
         if (*supported)
                 return ret;
 
-        ret = detect_mon_perf_support(event, supported, scale);
+        ret = os_cap_mon_perf_support(event, supported, scale);
         if (ret != PQOS_RETVAL_OK)
                 LOG_ERROR("Fatal error encountered while checking for perf "
                           "monitoring support\n");
@@ -540,8 +409,7 @@ detect_mon_support(const enum pqos_mon_event event,
 }
 
 int
-os_cap_mon_discover(struct pqos_cap_mon **r_cap,
-                    const struct pqos_cpuinfo *cpu)
+os_cap_mon_discover(struct pqos_cap_mon **r_cap, const struct pqos_cpuinfo *cpu)
 {
         struct pqos_cap_mon *cap = NULL;
         int supported;
@@ -550,15 +418,17 @@ os_cap_mon_discover(struct pqos_cap_mon **r_cap,
         unsigned i;
 
         enum pqos_mon_event events[] = {
+            /* clang-format off */
                 PQOS_MON_EVENT_L3_OCCUP,
                 PQOS_MON_EVENT_LMEM_BW,
                 PQOS_MON_EVENT_TMEM_BW,
                 PQOS_MON_EVENT_RMEM_BW,
                 PQOS_PERF_EVENT_LLC_MISS,
                 PQOS_PERF_EVENT_IPC
+            /* clang-format on */
         };
 
-        ret = detect_os_support(PROC_CPUINFO, "cqm", 0, &supported);
+        ret = pqos_file_contains(PROC_CPUINFO, "cqm", &supported);
         if (ret != PQOS_RETVAL_OK) {
                 LOG_ERROR("Fatal error encountered in"
                           " OS detection!\n");
@@ -567,14 +437,14 @@ os_cap_mon_discover(struct pqos_cap_mon **r_cap,
         if (!supported)
                 return PQOS_RETVAL_RESOURCE;
 
-        if (access(RESCTRL_PATH_INFO_L3_MON"/num_rmids", F_OK) == 0) {
-                ret = readuint64(RESCTRL_PATH_INFO_L3_MON"/num_rmids", 10,
-                                 &num_rmids);
+        if (pqos_file_exists(RESCTRL_PATH_INFO_L3_MON "/num_rmids")) {
+                ret = pqos_fread_uint64(RESCTRL_PATH_INFO_L3_MON "/num_rmids",
+                                        10, &num_rmids);
                 if (ret != PQOS_RETVAL_OK)
                         return ret;
         }
 
-        cap = (struct pqos_cap_mon *) malloc(sizeof(*cap));
+        cap = (struct pqos_cap_mon *)malloc(sizeof(*cap));
         if (cap == NULL)
                 return PQOS_RETVAL_RESOURCE;
         memset(cap, 0, sizeof(*cap));
@@ -602,6 +472,7 @@ os_cap_mon_discover(struct pqos_cap_mon **r_cap,
                 }
 
                 monitor = &(mon->events[mon->num_events]);
+                memset(monitor, 0, sizeof(*monitor));
                 monitor->type = events[i];
                 monitor->max_rmid = num_rmids;
                 monitor->scale_factor = scale;
@@ -621,109 +492,87 @@ os_cap_mon_discover(struct pqos_cap_mon **r_cap,
 }
 
 int
-os_cap_l3ca_discover(struct pqos_cap_l3ca **r_cap,
-                     const struct pqos_cpuinfo *cpu)
+os_cap_l3ca_discover(struct pqos_cap_l3ca *cap, const struct pqos_cpuinfo *cpu)
 {
-        struct pqos_cap_l3ca *cap = NULL;
-        struct stat st;
         const char *info;
         int cdp_on;
         int ret = PQOS_RETVAL_OK;
 
-        if (stat(RESCTRL_PATH_INFO_L3, &st) == 0) {
+        ASSERT(cap != NULL);
+
+        if (pqos_dir_exists(RESCTRL_PATH_INFO_L3)) {
                 info = RESCTRL_PATH_INFO_L3;
                 cdp_on = 0;
-        } else if (stat(RESCTRL_PATH_INFO_L3CODE, &st) == 0 &&
-                   stat(RESCTRL_PATH_INFO_L3DATA, &st) == 0) {
+        } else if (pqos_dir_exists(RESCTRL_PATH_INFO_L3CODE) &&
+                   pqos_dir_exists(RESCTRL_PATH_INFO_L3DATA)) {
                 info = RESCTRL_PATH_INFO_L3CODE;
                 cdp_on = 1;
         } else
                 return PQOS_RETVAL_RESOURCE;
 
-        cap = (struct pqos_cap_l3ca *)calloc(1, sizeof(*cap));
-        if (cap == NULL)
-                return PQOS_RETVAL_RESOURCE;
-
-        ASSERT(cap != NULL);
+        memset(cap, 0, sizeof(*cap));
         cap->mem_size = sizeof(*cap);
         cap->cdp = cdp_on;
         cap->cdp_on = cdp_on;
         cap->way_size = cpu->l3.way_size;
 
-        ret = get_num_closids(info, &cap->num_classes);
+        ret = resctrl_alloc_get_num_closids(&cap->num_classes);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_l3ca_discover_exit;
+                return ret;
 
         ret = get_num_ways(info, &cap->num_ways);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_l3ca_discover_exit;
+                return ret;
 
         ret = get_shareable_bits(info, &cap->way_contention);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_l3ca_discover_exit;
+                return ret;
 
         if (!cdp_on)
-                ret = detect_os_support(PROC_CPUINFO, "cdp_l3", 0, &cap->cdp);
-
- os_cap_l3ca_discover_exit:
-        if (ret == PQOS_RETVAL_OK)
-                *r_cap = cap;
-        else
-                free(cap);
+                ret = pqos_file_contains(PROC_CPUINFO, "cdp_l3", &cap->cdp);
 
         return ret;
 }
 
 int
-os_cap_l2ca_discover(struct pqos_cap_l2ca **r_cap,
-                     const struct pqos_cpuinfo *cpu)
+os_cap_l2ca_discover(struct pqos_cap_l2ca *cap, const struct pqos_cpuinfo *cpu)
 {
-        struct pqos_cap_l2ca *cap = NULL;
-        struct stat st;
         const char *info;
         int cdp_on;
         int ret = PQOS_RETVAL_OK;
 
-        if (stat(RESCTRL_PATH_INFO_L2, &st) == 0) {
+        ASSERT(cap != NULL);
+
+        if (pqos_dir_exists(RESCTRL_PATH_INFO_L2)) {
                 info = RESCTRL_PATH_INFO_L2;
                 cdp_on = 0;
-        } else if (stat(RESCTRL_PATH_INFO_L2CODE, &st) == 0 &&
-                   stat(RESCTRL_PATH_INFO_L2DATA, &st) == 0) {
+        } else if (pqos_dir_exists(RESCTRL_PATH_INFO_L2CODE) &&
+                   pqos_dir_exists(RESCTRL_PATH_INFO_L2DATA)) {
                 info = RESCTRL_PATH_INFO_L2CODE;
                 cdp_on = 1;
         } else
                 return PQOS_RETVAL_RESOURCE;
 
-        cap = (struct pqos_cap_l2ca *)calloc(1, sizeof(*cap));
-        if (cap == NULL)
-                return PQOS_RETVAL_RESOURCE;
-
-        ASSERT(cap != NULL);
+        memset(cap, 0, sizeof(*cap));
         cap->mem_size = sizeof(*cap);
         cap->cdp = cdp_on;
         cap->cdp_on = cdp_on;
         cap->way_size = cpu->l2.way_size;
 
-        ret = get_num_closids(info, &cap->num_classes);
+        ret = resctrl_alloc_get_num_closids(&cap->num_classes);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_l2ca_discover_exit;
+                return ret;
 
         ret = get_num_ways(info, &cap->num_ways);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_l2ca_discover_exit;
+                return ret;
 
         ret = get_shareable_bits(info, &cap->way_contention);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_l2ca_discover_exit;
+                return ret;
 
         if (!cdp_on)
-                ret = detect_os_support(PROC_CPUINFO, "cdp_l2", 0, &cap->cdp);
-
- os_cap_l2ca_discover_exit:
-        if (ret == PQOS_RETVAL_OK)
-                *r_cap = cap;
-        else
-                free(cap);
+                ret = pqos_file_contains(PROC_CPUINFO, "cdp_l2", &cap->cdp);
 
         return ret;
 }
@@ -747,12 +596,12 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                 return PQOS_RETVAL_OK;
         }
 
-        if (access(RESCTRL_PATH"/cpus", F_OK) != 0)
+        if (!pqos_file_exists(RESCTRL_PATH "/cpus"))
                 *enabled = 0;
 
         /* check mount flags */
         if (*enabled == -1) {
-                ret = detect_os_support(PROC_MOUNTS, "mba_MBps", 0, enabled);
+                ret = pqos_file_contains(PROC_MOUNTS, "mba_MBps", enabled);
                 if (ret != PQOS_RETVAL_OK)
                         return ret;
         }
@@ -762,20 +611,20 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                 unsigned grp;
                 unsigned count = 0;
                 unsigned i;
-		unsigned *mba_ids, mba_id_num;
+                unsigned *mba_ids, mba_id_num;
                 struct resctrl_schemata *schmt;
 
                 ret = resctrl_alloc_get_grps_num(cap, &count);
                 if (ret != PQOS_RETVAL_OK)
                         return ret;
 
-		mba_ids = pqos_cpu_get_mba_ids(cpu, &mba_id_num);
-		if (mba_ids == NULL)
+                mba_ids = pqos_cpu_get_mba_ids(cpu, &mba_id_num);
+                if (mba_ids == NULL)
                         return PQOS_RETVAL_ERROR;
 
                 schmt = resctrl_schemata_alloc(cap, cpu);
                 if (schmt == NULL) {
-			free(mba_ids);
+                        free(mba_ids);
                         return PQOS_RETVAL_ERROR;
                 }
 
@@ -784,12 +633,11 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                         if (ret != PQOS_RETVAL_OK)
                                 continue;
 
-			for (i = 0; i < mba_id_num; i++) {
+                        for (i = 0; i < mba_id_num; i++) {
                                 struct pqos_mba mba;
 
-				ret = resctrl_schemata_mba_get(schmt,
-							       mba_ids[i],
-							       &mba);
+                                ret = resctrl_schemata_mba_get(
+                                    schmt, mba_ids[i], &mba);
                                 if (ret == PQOS_RETVAL_OK && mba.mb_max > 100) {
                                         *enabled = 1;
                                         break;
@@ -798,7 +646,7 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                 }
 
                 resctrl_schemata_free(schmt);
-		free(mba_ids);
+                free(mba_ids);
         }
 
         /* get free COS and try to write value above 100 */
@@ -835,7 +683,8 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                         }
                         /* restore MBA configuration */
                         if (*enabled == 1) {
-                                ret = resctrl_alloc_schemata_write(grp, schmt);
+                                ret = resctrl_alloc_schemata_write(
+                                    grp, PQOS_TECHNOLOGY_MBA, schmt);
                                 if (ret != PQOS_RETVAL_OK)
                                         LOG_WARN("Unable to restore MBA "
                                                  "settings\n");
@@ -845,7 +694,7 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                 resctrl_schemata_free(schmt);
         }
 
- ctrl_support:
+ctrl_support:
         if (*supported != -1)
                 goto ctrl_exit;
 
@@ -856,7 +705,7 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
         else {
                 int mbl = 0;
 
-                ret = detect_mon_resctrl_support(PQOS_MON_EVENT_LMEM_BW, &mbl,
+                ret = os_cap_mon_resctrl_support(PQOS_MON_EVENT_LMEM_BW, &mbl,
                                                  NULL);
                 if (ret != PQOS_RETVAL_OK)
                         return ret;
@@ -864,7 +713,7 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                         *supported = 0;
         }
 
- ctrl_exit:
+ctrl_exit:
         if (*supported == 0)
                 *enabled = 0;
 
@@ -879,65 +728,54 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
 }
 
 int
-os_cap_mba_discover(struct pqos_cap_mba **r_cap,
-                    const struct pqos_cpuinfo *cpu)
+os_cap_mba_discover(struct pqos_cap_mba *cap, const struct pqos_cpuinfo *cpu)
 {
-        struct pqos_cap_mba *cap = NULL;
-        struct stat st;
         uint64_t val;
-        const char *info = RESCTRL_PATH_INFO_MB;
         int ret = PQOS_RETVAL_OK;
 
         UNUSED_PARAM(cpu);
-
-        if (stat(RESCTRL_PATH_INFO_MB, &st) != 0)
-                return PQOS_RETVAL_RESOURCE;
-
-        cap = (struct pqos_cap_mba *)calloc(1, sizeof(*cap));
-        if (cap == NULL)
-                return PQOS_RETVAL_RESOURCE;
-
         ASSERT(cap != NULL);
+
+        if (!pqos_dir_exists(RESCTRL_PATH_INFO_MB))
+                return PQOS_RETVAL_RESOURCE;
+
+        memset(cap, 0, sizeof(*cap));
         cap->mem_size = sizeof(*cap);
         cap->ctrl = -1;
         cap->ctrl_on = -1;
 
-        ret = get_num_closids(info, &cap->num_classes);
+        ret = resctrl_alloc_get_num_closids(&cap->num_classes);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_mba_discover_exit;
+                return ret;
 
         /* Detect MBA CTRL status */
-        ret = detect_os_support(PROC_MOUNTS, "mba_MBps", 0, &(cap->ctrl_on));
+        ret = pqos_file_contains(PROC_MOUNTS, "mba_MBps", &(cap->ctrl_on));
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_mba_discover_exit;
+                return ret;
         if (cap->ctrl_on == 1)
                 cap->ctrl = 1;
         else
                 cap->ctrl = mba_ctrl;
 
-        ret = readuint64(RESCTRL_PATH_INFO_MB"/min_bandwidth", 10, &val);
+        ret =
+            pqos_fread_uint64(RESCTRL_PATH_INFO_MB "/min_bandwidth", 10, &val);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_mba_discover_exit;
+                return ret;
         else
                 cap->throttle_max = 100 - val;
 
-        ret = readuint64(RESCTRL_PATH_INFO_MB"/bandwidth_gran", 10, &val);
+        ret =
+            pqos_fread_uint64(RESCTRL_PATH_INFO_MB "/bandwidth_gran", 10, &val);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_mba_discover_exit;
+                return ret;
         else
                 cap->throttle_step = val;
 
-        ret = readuint64(RESCTRL_PATH_INFO_MB"/delay_linear", 10, &val);
+        ret = pqos_fread_uint64(RESCTRL_PATH_INFO_MB "/delay_linear", 10, &val);
         if (ret != PQOS_RETVAL_OK)
-                goto os_cap_mba_discover_exit;
+                return ret;
         else
                 cap->is_linear = (val == 1);
 
- os_cap_mba_discover_exit:
-        if (ret == PQOS_RETVAL_OK)
-                *r_cap = cap;
-        else
-                free(cap);
-
         return ret;
 }
