@@ -1,8 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017-2019 Intel Corporation. All rights reserved.
- * All rights reserved.
+ * Copyright(c) 2017-2021 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -34,13 +33,14 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>             /**< pid_t */
-#include <dirent.h>             /**< scandir() */
+#include <unistd.h> /**< pid_t */
+#include <dirent.h> /**< scandir() */
 
 #include "pqos.h"
 #include "cap.h"
 #include "log.h"
 #include "types.h"
+#include "monitoring.h"
 #include "os_monitoring.h"
 #include "perf_monitoring.h"
 #include "resctrl.h"
@@ -55,12 +55,12 @@ static const struct pqos_cpuinfo *m_cpu = NULL;
 
 /** List of non virtual events */
 const enum pqos_mon_event os_mon_event[] = {
-        PQOS_MON_EVENT_L3_OCCUP,
-        PQOS_MON_EVENT_LMEM_BW,
-        PQOS_MON_EVENT_TMEM_BW,
-        PQOS_PERF_EVENT_LLC_MISS,
-        (enum pqos_mon_event)PQOS_PERF_EVENT_CYCLES,
-        (enum pqos_mon_event)PQOS_PERF_EVENT_INSTRUCTIONS};
+    PQOS_MON_EVENT_L3_OCCUP,
+    PQOS_MON_EVENT_LMEM_BW,
+    PQOS_MON_EVENT_TMEM_BW,
+    PQOS_PERF_EVENT_LLC_MISS,
+    (enum pqos_mon_event)PQOS_PERF_EVENT_CYCLES,
+    (enum pqos_mon_event)PQOS_PERF_EVENT_INSTRUCTIONS};
 
 /**
  * @brief Filter directory filenames
@@ -77,7 +77,7 @@ const enum pqos_mon_event os_mon_event[] = {
 static int
 filter(const struct dirent *dir)
 {
-	return (dir->d_name[0] == '.') ? 0 : 1;
+        return (dir->d_name[0] == '.') ? 0 : 1;
 }
 
 /**
@@ -104,50 +104,52 @@ stop_events(struct pqos_mon_data *group)
                 /**
                  * Stop perf event
                  */
-                if (group->perf_event & evt) {
+                if (group->intl->perf.event & evt) {
                         ret = perf_mon_stop(group, evt);
                         if (ret == PQOS_RETVAL_OK)
                                 stopped_evts |= evt;
                 }
         }
 
-        if (group->resctrl_event) {
+        if (group->intl->resctrl.event) {
                 ret = resctrl_lock_exclusive();
                 if (ret != PQOS_RETVAL_OK)
                         goto stop_event_error;
 
                 ret = resctrl_mon_stop(group);
                 if (ret == PQOS_RETVAL_OK)
-                        stopped_evts |= group->resctrl_event;
+                        stopped_evts |= group->intl->resctrl.event;
 
                 resctrl_lock_release();
         }
 
- stop_event_error:
+stop_event_error:
         if ((stopped_evts & PQOS_MON_EVENT_LMEM_BW) &&
-                (stopped_evts & PQOS_MON_EVENT_TMEM_BW))
+            (stopped_evts & PQOS_MON_EVENT_TMEM_BW))
                 stopped_evts |= (enum pqos_mon_event)PQOS_MON_EVENT_RMEM_BW;
 
         if ((stopped_evts & PQOS_PERF_EVENT_CYCLES) &&
-                (stopped_evts & PQOS_PERF_EVENT_INSTRUCTIONS))
+            (stopped_evts & PQOS_PERF_EVENT_INSTRUCTIONS))
                 stopped_evts |= (enum pqos_mon_event)PQOS_PERF_EVENT_IPC;
 
-        if (group->perf != NULL) {
-                free(group->perf);
-                group->perf = NULL;
+        if (group->intl->perf.ctx != NULL) {
+                free(group->intl->perf.ctx);
+                group->intl->perf.ctx = NULL;
         }
 
-        if ((group->perf_event & stopped_evts) != group->perf_event) {
+        if ((group->intl->perf.event & stopped_evts) !=
+            group->intl->perf.event) {
                 LOG_ERROR("Failed to stop all perf events\n");
                 return PQOS_RETVAL_ERROR;
         }
-        group->perf_event = (enum pqos_mon_event)0;
+        group->intl->perf.event = (enum pqos_mon_event)0;
 
-        if ((group->resctrl_event & stopped_evts) != group->resctrl_event) {
+        if ((group->intl->resctrl.event & stopped_evts) !=
+            group->intl->resctrl.event) {
                 LOG_ERROR("Failed to stop resctrl events\n");
                 return PQOS_RETVAL_ERROR;
         }
-        group->resctrl_event = (enum pqos_mon_event)0;
+        group->intl->resctrl.event = (enum pqos_mon_event)0;
 
         return PQOS_RETVAL_OK;
 }
@@ -179,19 +181,20 @@ start_events(struct pqos_mon_data *group)
                 return PQOS_RETVAL_ERROR;
 
         events = group->event;
-        group->perf_event = (enum pqos_mon_event)0;
-        group->perf = malloc(sizeof(group->perf[0]) * num_ctrs);
-        if (group->perf == NULL) {
+        group->intl->perf.event = (enum pqos_mon_event)0;
+        group->intl->perf.ctx =
+            malloc(sizeof(group->intl->perf.ctx[0]) * num_ctrs);
+        if (group->intl->perf.ctx == NULL) {
                 LOG_ERROR("Memory allocation failed\n");
                 return PQOS_RETVAL_ERROR;
         }
 
         if (events & PQOS_MON_EVENT_RMEM_BW)
                 events |= (enum pqos_mon_event)(PQOS_MON_EVENT_LMEM_BW |
-                           PQOS_MON_EVENT_TMEM_BW);
+                                                PQOS_MON_EVENT_TMEM_BW);
         if (events & PQOS_PERF_EVENT_IPC)
                 events |= (enum pqos_mon_event)(PQOS_PERF_EVENT_CYCLES |
-                           PQOS_PERF_EVENT_INSTRUCTIONS);
+                                                PQOS_PERF_EVENT_INSTRUCTIONS);
 
         /**
          * Determine selected events and Perf counters
@@ -204,12 +207,12 @@ start_events(struct pqos_mon_data *group)
                                 ret = perf_mon_start(group, evt);
                                 if (ret != PQOS_RETVAL_OK)
                                         goto start_event_error;
-                                group->perf_event |= evt;
+                                group->intl->perf.event |= evt;
                                 continue;
                         }
 
                         if (resctrl_mon_is_event_supported(evt)) {
-                                group->resctrl_event |= evt;
+                                group->intl->resctrl.event |= evt;
                                 continue;
                         }
 
@@ -220,9 +223,9 @@ start_events(struct pqos_mon_data *group)
                         goto start_event_error;
                 }
         }
-        started_evts |= group->perf_event;
+        started_evts |= group->intl->perf.event;
 
-        if (group->resctrl_event != 0) {
+        if (group->intl->resctrl.event != 0) {
                 ret = resctrl_lock_exclusive();
                 if (ret != PQOS_RETVAL_OK)
                         goto start_event_error;
@@ -232,13 +235,13 @@ start_events(struct pqos_mon_data *group)
                 if (ret != PQOS_RETVAL_OK)
                         goto start_event_error;
         }
-        started_evts |= group->resctrl_event;
+        started_evts |= group->intl->resctrl.event;
 
         /**
          * All events required by RMEM has been started
          */
         if ((started_evts & PQOS_MON_EVENT_LMEM_BW) &&
-                (started_evts & PQOS_MON_EVENT_TMEM_BW)) {
+            (started_evts & PQOS_MON_EVENT_TMEM_BW)) {
                 group->values.mbm_remote = 0;
                 started_evts |= (enum pqos_mon_event)PQOS_MON_EVENT_RMEM_BW;
         }
@@ -246,19 +249,19 @@ start_events(struct pqos_mon_data *group)
          * All events required by IPC has been started
          */
         if ((started_evts & PQOS_PERF_EVENT_CYCLES) &&
-                (started_evts & PQOS_PERF_EVENT_INSTRUCTIONS)) {
+            (started_evts & PQOS_PERF_EVENT_INSTRUCTIONS)) {
                 group->values.ipc = 0;
                 started_evts |= (enum pqos_mon_event)PQOS_PERF_EVENT_IPC;
         }
 
- start_event_error:
+start_event_error:
         /*  Check if all selected events were started */
         if ((group->event & started_evts) != group->event) {
                 stop_events(group);
                 LOG_ERROR("Failed to start all selected "
                           "OS monitoring events\n");
-                free(group->perf);
-                group->perf = NULL;
+                free(group->intl->perf.ctx);
+                group->intl->perf.ctx = NULL;
         }
         return ret;
 }
@@ -278,7 +281,7 @@ poll_events(struct pqos_mon_data *group)
         unsigned i;
         int ret = PQOS_RETVAL_OK;
 
-        if (group->resctrl_event != 0) {
+        if (group->intl->resctrl.event != 0) {
                 ret = resctrl_lock_shared();
                 if (ret != PQOS_RETVAL_OK)
                         return ret;
@@ -290,7 +293,7 @@ poll_events(struct pqos_mon_data *group)
                 /**
                  * poll perf event
                  */
-                if (group->perf_event & evt) {
+                if (group->intl->perf.event & evt) {
                         ret = perf_mon_poll(group, evt);
                         if (ret != PQOS_RETVAL_OK)
                                 goto poll_events_exit;
@@ -299,7 +302,7 @@ poll_events(struct pqos_mon_data *group)
                 /**
                  * poll resctrl event
                  */
-                if (group->resctrl_event & evt) {
+                if (group->intl->resctrl.event & evt) {
                         ret = resctrl_mon_poll(group, evt);
                         if (ret != PQOS_RETVAL_OK)
                                 goto poll_events_exit;
@@ -314,20 +317,20 @@ poll_events(struct pqos_mon_data *group)
                 if (group->values.mbm_total_delta >
                     group->values.mbm_local_delta)
                         group->values.mbm_remote_delta =
-                                group->values.mbm_total_delta -
-                                group->values.mbm_local_delta;
+                            group->values.mbm_total_delta -
+                            group->values.mbm_local_delta;
         }
         if (group->event & PQOS_PERF_EVENT_IPC) {
                 if (group->values.ipc_unhalted_delta > 0)
                         group->values.ipc =
-                                (double)group->values.ipc_retired_delta /
-                                (double)group->values.ipc_unhalted_delta;
+                            (double)group->values.ipc_retired_delta /
+                            (double)group->values.ipc_unhalted_delta;
                 else
                         group->values.ipc = 0;
         }
 
- poll_events_exit:
-        if (group->resctrl_event != 0)
+poll_events_exit:
+        if (group->intl->resctrl.event != 0)
                 resctrl_lock_release();
 
         return ret;
@@ -341,8 +344,8 @@ os_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
         ASSERT(cpu != NULL);
         ASSERT(cap != NULL);
 
-	if (cpu == NULL || cap == NULL)
-		return PQOS_RETVAL_PARAM;
+        if (cpu == NULL || cap == NULL)
+                return PQOS_RETVAL_PARAM;
 
         ret = perf_mon_init(cpu, cap);
         if (ret == PQOS_RETVAL_RESOURCE)
@@ -351,7 +354,7 @@ os_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
-	m_cpu = cpu;
+        m_cpu = cpu;
 
         return ret;
 }
@@ -424,7 +427,7 @@ os_mon_start(const unsigned num_cores,
          */
         for (i = 0; i < (sizeof(event) * 8); i++) {
                 const enum pqos_mon_event evt_mask =
-                        (enum pqos_mon_event)(1U << i);
+                    (enum pqos_mon_event)(1U << i);
                 const struct pqos_monitor *ptr = NULL;
 
                 if (!(evt_mask & event))
@@ -449,10 +452,9 @@ os_mon_start(const unsigned num_cores,
         /**
          * Fill in the monitoring group structure
          */
-        memset(group, 0, sizeof(*group));
         group->event = event;
         group->context = context;
-        group->cores = (unsigned *) malloc(sizeof(group->cores[0]) * num_cores);
+        group->cores = (unsigned *)malloc(sizeof(group->cores[0]) * num_cores);
         if (group->cores == NULL)
                 return PQOS_RETVAL_RESOURCE;
 
@@ -526,8 +528,8 @@ tid_add(const pid_t tid, unsigned *tid_nr, pid_t **tid_map)
  * @brief Find process TID's and add them to the list
  *
  * @param[in] pid peocess id
- * @param[inout] tid_nr numer of tids
- * @param[inout] tid_map tid mapping
+ * @param[in,out] tid_nr number of tids
+ * @param[in,out] tid_map tid mapping
  *
  * @return Operations status
  * @retval PQOS_RETVAL_OK on success
@@ -558,8 +560,8 @@ tid_find(const pid_t pid, unsigned *tid_nr, pid_t **tid_map)
                 ret = tid_add(pid, tid_nr, tid_map);
         else
                 for (i = 0; i < num_tasks; i++) {
-                        ret = tid_add((pid_t)atoi(namelist[i]->d_name),
-                                      tid_nr, tid_map);
+                        ret = tid_add((pid_t)atoi(namelist[i]->d_name), tid_nr,
+                                      tid_map);
                         if (ret != PQOS_RETVAL_OK)
                                 break;
                 }
@@ -634,8 +636,7 @@ os_mon_start_pids(const unsigned num_pids,
                         goto os_mon_start_pids_exit;
         }
 
-        memset(group, 0, sizeof(*group));
-        group->pids = (pid_t *) malloc(sizeof(pid_t) * num_pids);
+        group->pids = (pid_t *)malloc(sizeof(pid_t) * num_pids);
         if (group->pids == NULL) {
                 ret = PQOS_RETVAL_RESOURCE;
                 goto os_mon_start_pids_exit;
@@ -652,7 +653,7 @@ os_mon_start_pids(const unsigned num_pids,
 
         ret = start_events(group);
 
- os_mon_start_pids_exit:
+os_mon_start_pids_exit:
         if (ret != PQOS_RETVAL_OK && tid_map != NULL)
                 free(tid_map);
 
@@ -725,9 +726,14 @@ os_mon_add_pids(const unsigned num_pids,
         added.tid_map = tid_map;
         added.event = group->event;
         added.num_pids = num_pids;
-        if (group->resctrl_mon_group != NULL) {
-                added.resctrl_mon_group = strdup(group->resctrl_mon_group);
-                if (added.resctrl_mon_group == NULL) {
+        added.intl = malloc(sizeof(*added.intl));
+        if (added.intl == NULL)
+                goto os_mon_add_pids_exit;
+        memset(added.intl, 0, sizeof(*added.intl));
+        if (group->intl->resctrl.mon_group != NULL) {
+                added.intl->resctrl.mon_group =
+                    strdup(group->intl->resctrl.mon_group);
+                if (added.intl->resctrl.mon_group == NULL) {
                         ret = PQOS_RETVAL_RESOURCE;
                         goto os_mon_add_pids_exit;
                 }
@@ -740,24 +746,25 @@ os_mon_add_pids(const unsigned num_pids,
         /**
          * Update mon group
          */
-        ptr = realloc(group->tid_map,
-                sizeof(group->tid_map[0]) * (group->tid_nr + added.tid_nr));
+        ptr = realloc(group->tid_map, sizeof(group->tid_map[0]) *
+                                          (group->tid_nr + added.tid_nr));
         if (ptr == NULL) {
                 ret = PQOS_RETVAL_RESOURCE;
                 goto os_mon_add_pids_exit;
         }
         group->tid_map = ptr;
 
-        ctx = realloc(group->perf,
-                sizeof(group->perf[0]) * (group->tid_nr + added.tid_nr));
+        ctx =
+            realloc(group->intl->perf.ctx, sizeof(group->intl->perf.ctx[0]) *
+                                               (group->tid_nr + added.tid_nr));
         if (ctx == NULL) {
                 ret = PQOS_RETVAL_RESOURCE;
                 goto os_mon_add_pids_exit;
         }
-        group->perf = ctx;
+        group->intl->perf.ctx = ctx;
 
         ptr = realloc(group->pids,
-                sizeof(group->pids[0]) * (group->num_pids + num_pids));
+                      sizeof(group->pids[0]) * (group->num_pids + num_pids));
         if (ptr == NULL) {
                 ret = PQOS_RETVAL_RESOURCE;
                 goto os_mon_add_pids_exit;
@@ -766,7 +773,7 @@ os_mon_add_pids(const unsigned num_pids,
 
         for (i = 0; i < added.tid_nr; i++) {
                 group->tid_map[group->tid_nr] = added.tid_map[i];
-                group->perf[group->tid_nr] = added.perf[i];
+                group->intl->perf.ctx[group->tid_nr] = added.intl->perf.ctx[i];
                 group->tid_nr++;
         }
         for (i = 0; i < num_pids; i++) {
@@ -774,17 +781,20 @@ os_mon_add_pids(const unsigned num_pids,
                 group->num_pids++;
         }
 
- os_mon_add_pids_exit:
-        if (added.resctrl_mon_group != NULL) {
-                free(added.resctrl_mon_group);
-                added.resctrl_mon_group = NULL;
+os_mon_add_pids_exit:
+        if (added.intl != NULL && added.intl->resctrl.mon_group != NULL) {
+                free(added.intl->resctrl.mon_group);
+                added.intl->resctrl.mon_group = NULL;
         }
         if (ret == PQOS_RETVAL_RESOURCE) {
                 LOG_ERROR("Memory allocation error!\n");
                 stop_events(&added);
         }
-        if (added.perf != NULL)
-                free(added.perf);
+        if (added.intl != NULL) {
+                if (added.intl->perf.ctx != NULL)
+                        free(added.intl->perf.ctx);
+                free(added.intl);
+        }
         if (tid_map != NULL)
                 free(tid_map);
         return ret;
@@ -807,6 +817,8 @@ os_mon_remove_pids(const unsigned num_pids,
         ASSERT(pids != NULL);
         ASSERT(group != NULL);
 
+        memset(&remove, 0, sizeof(remove));
+
         /**
          * Find TID's for not removed tasks
          */
@@ -824,19 +836,22 @@ os_mon_remove_pids(const unsigned num_pids,
                         goto os_mon_remove_pids_exit;
         }
 
-        memset(&remove, 0, sizeof(remove));
-        remove.perf_event = group->perf_event;
-        remove.resctrl_event = group->resctrl_event;
+        remove.intl =
+            (struct pqos_mon_data_internal *)malloc(sizeof(*remove.intl));
+        if (remove.intl == NULL)
+                goto os_mon_remove_pids_exit;
+        memset(remove.intl, 0, sizeof(*remove.intl));
+        remove.intl->perf.event = group->intl->perf.event;
+        remove.intl->resctrl.event = group->intl->resctrl.event;
         remove.pids = NULL;
         remove.num_pids = num_pids;
         remove.tid_map = malloc(sizeof(remove.tid_map[0]) * group->tid_nr);
         if (remove.tid_map == NULL)
                 goto os_mon_remove_pids_exit;
-        remove.perf = malloc(sizeof(remove.perf[0]) * group->tid_nr);
-        if (remove.perf == NULL) {
-                free(remove.tid_map);
+        remove.intl->perf.ctx =
+            malloc(sizeof(remove.intl->perf.ctx[0]) * group->tid_nr);
+        if (remove.intl->perf.ctx == NULL)
                 goto os_mon_remove_pids_exit;
-        }
 
         /* Add tid's for removal */
         for (i = 0; i < group->tid_nr; i++) {
@@ -845,13 +860,11 @@ os_mon_remove_pids(const unsigned num_pids,
                         continue;
 
                 remove.tid_map[remove.tid_nr] = group->tid_map[i];
-                remove.perf[remove.tid_nr] = group->perf[i];
+                remove.intl->perf.ctx[remove.tid_nr] = group->intl->perf.ctx[i];
                 remove.tid_nr++;
         }
 
         ret = stop_events(&remove);
-        free(remove.perf);
-        free(remove.tid_map);
         if (ret != PQOS_RETVAL_OK)
                 goto os_mon_remove_pids_exit;
 
@@ -867,13 +880,14 @@ os_mon_remove_pids(const unsigned num_pids,
                 }
 
                 group->tid_map[i - removed] = group->tid_map[i];
-                group->perf[i - removed] = group->perf[i];
+                group->intl->perf.ctx[i - removed] = group->intl->perf.ctx[i];
         }
         group->tid_nr -= removed;
-        group->tid_map = realloc(group->tid_map,
-                                 sizeof(group->tid_map[0]) * group->tid_nr);
-        group->perf = realloc(group->perf,
-                              sizeof(group->perf[0]) * group->tid_nr);
+        group->tid_map =
+            realloc(group->tid_map, sizeof(group->tid_map[0]) * group->tid_nr);
+        group->intl->perf.ctx =
+            realloc(group->intl->perf.ctx,
+                    sizeof(group->intl->perf.ctx[0]) * group->tid_nr);
         removed = 0;
         for (i = 0; i < group->num_pids; i++) {
                 if (tid_exists(group->pids[i], num_pids, pids)) {
@@ -884,18 +898,24 @@ os_mon_remove_pids(const unsigned num_pids,
                 group->pids[i - removed] = group->pids[i];
         }
         group->num_pids -= removed;
-        group->pids = realloc(group->pids,
-                sizeof(group->pids[0]) * group->num_pids);
+        group->pids =
+            realloc(group->pids, sizeof(group->pids[0]) * group->num_pids);
 
- os_mon_remove_pids_exit:
+os_mon_remove_pids_exit:
+        if (remove.tid_map != NULL)
+                free(remove.tid_map);
+        if (remove.intl != NULL) {
+                if (remove.intl->perf.ctx)
+                        free(remove.intl->perf.ctx);
+                free(remove.intl);
+        }
         if (keep_tid_map != NULL)
                 free(keep_tid_map);
         return ret;
 }
 
 int
-os_mon_poll(struct pqos_mon_data **groups,
-              const unsigned num_groups)
+os_mon_poll(struct pqos_mon_data **groups, const unsigned num_groups)
 {
         unsigned i = 0;
 
@@ -907,7 +927,8 @@ os_mon_poll(struct pqos_mon_data **groups,
 
                 if (ret != PQOS_RETVAL_OK)
                         LOG_WARN("Failed to poll event on "
-                                 "group number %u\n", i);
+                                 "group number %u\n",
+                                 i);
         }
 
         return PQOS_RETVAL_OK;
