@@ -1,8 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
- * All rights reserved.
+ * Copyright(c) 2014-2021 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -57,24 +56,25 @@ extern "C" {
  * =======================================
  */
 
-#define PQOS_VERSION 30200   /**< version 3.2.0 */
-#define PQOS_MAX_L3CA_COS 16 /**< 16 x COS */
-#define PQOS_MAX_L2CA_COS 16 /**< 16 x COS */
+#define PQOS_VERSION      40200 /**< version 4.2.0 */
+#define PQOS_MAX_COS      16    /** 16 x COS */
+#define PQOS_MAX_L3CA_COS PQOS_MAX_COS
+#define PQOS_MAX_L2CA_COS PQOS_MAX_COS
 
 /*
  * =======================================
  * Return values
  * =======================================
  */
-#define PQOS_RETVAL_OK 0        /**< everything OK */
-#define PQOS_RETVAL_ERROR 1     /**< generic error */
-#define PQOS_RETVAL_PARAM 2     /**< parameter error */
-#define PQOS_RETVAL_RESOURCE 3  /**< resource error */
-#define PQOS_RETVAL_INIT 4      /**< initialization error */
+#define PQOS_RETVAL_OK        0 /**< everything OK */
+#define PQOS_RETVAL_ERROR     1 /**< generic error */
+#define PQOS_RETVAL_PARAM     2 /**< parameter error */
+#define PQOS_RETVAL_RESOURCE  3 /**< resource error */
+#define PQOS_RETVAL_INIT      4 /**< initialization error */
 #define PQOS_RETVAL_TRANSPORT 5 /**< transport error */
-#define PQOS_RETVAL_PERF_CTR 6  /**< performance counter error */
-#define PQOS_RETVAL_BUSY 7      /**< resource busy error */
-#define PQOS_RETVAL_INTER 8     /**< Interface not supported */
+#define PQOS_RETVAL_PERF_CTR  6 /**< performance counter error */
+#define PQOS_RETVAL_BUSY      7 /**< resource busy error */
+#define PQOS_RETVAL_INTER     8 /**< Interface not supported */
 
 /*
  * =======================================
@@ -293,6 +293,7 @@ struct pqos_monitor {
         enum pqos_mon_event type; /**< event type */
         unsigned max_rmid;        /**< max RMID supported for this event */
         uint32_t scale_factor;    /**< factor to scale RMID value to bytes */
+        unsigned counter_length;  /**< counter bit length */
 };
 
 struct pqos_cap_mon {
@@ -353,6 +354,17 @@ struct pqos_cacheinfo {
         unsigned way_size;       /**< Cache way size in bytes */
 };
 
+/**
+ * =======================================
+ * Vendor values
+ * =======================================
+ */
+enum pqos_vendor {
+        PQOS_VENDOR_UNKNOWN = 0, /**< UNKNOWN */
+        PQOS_VENDOR_INTEL = 1,   /**< INTEL */
+        PQOS_VENDOR_AMD = 2      /**< AMD */
+};
+
 /**
  * CPU topology structure
  */
@@ -360,6 +372,7 @@ struct pqos_cpuinfo {
         unsigned mem_size;        /**< byte size of the structure */
         struct pqos_cacheinfo l2; /**< L2 cache information */
         struct pqos_cacheinfo l3; /**< L3 cache information */
+        enum pqos_vendor vendor;  /**< vendor Intel/AMD */
         unsigned num_cores;       /**< number of cores in the system */
         struct pqos_coreinfo cores[0];
 };
@@ -405,26 +418,7 @@ struct pqos_event_values {
         uint64_t llc_misses_delta;   /**< LLC misses - delta */
 };
 
-/**
- * Core monitoring poll context
- */
-struct pqos_mon_poll_ctx {
-        unsigned lcore;
-        unsigned cluster;
-        pqos_rmid_t rmid;
-};
-
-/**
- * Perf monitoring poll context
- */
-struct pqos_mon_perf_ctx {
-        int fd_llc;
-        int fd_mbl;
-        int fd_mbt;
-        int fd_inst;
-        int fd_cyc;
-        int fd_llc_misses;
-};
+struct pqos_mon_data_internal;
 
 /**
  * Monitoring group data structure
@@ -447,32 +441,13 @@ struct pqos_mon_data {
         unsigned tid_nr;
         pid_t *tid_map;
 
-        /**
-         * Perf specific section
-         */
-        struct pqos_mon_perf_ctx *perf; /**< Perf poll context for each
-                                           core/tid */
-        enum pqos_mon_event perf_event; /**< Started perf events */
-
-        /**
-         * Resctrl specific section
-         */
-        enum pqos_mon_event resctrl_event;
-        char *resctrl_mon_group;
-        struct pqos_event_values resctrl_values_storage; /**< stores values
-                                                         of monitoring group
-                                                         that was moved to
-                                                         another COS */
-
         /**
          * Core specific section
          */
-        struct pqos_mon_poll_ctx *poll_ctx; /**< core, cluster & RMID */
-        unsigned num_poll_ctx;              /**< number of poll contexts */
-        unsigned *cores;                    /**< list of cores in the group */
-        unsigned num_cores;                 /**< number of cores in the group */
-        int valid_mbm_read;                 /**< flag to discard 1st invalid
-                                               read */
+        unsigned *cores;    /**< list of cores in the group */
+        unsigned num_cores; /**< number of cores in the group */
+
+        struct pqos_mon_data_internal *intl; /**< internal data */
 };
 
 /**
@@ -1252,6 +1227,16 @@ int pqos_mba_ctrl_enabled(const struct pqos_cap *cap,
                           int *ctrl_supported,
                           int *ctrl_enabled);
 
+/**
+ * @brief returns the CPU vendor identification
+ *
+ * @param [in] cpu CPU information structure from \a pqos_cap_get
+ * @retval 0 if vendor unknown
+ * @return 1 if the vendor is Intel
+ * @return 2 if the vendor is AMD
+ */
+enum pqos_vendor pqos_get_vendor(const struct pqos_cpuinfo *cpu);
+
 /**
  * @brief Retrieves a monitoring value from a group for a specific event.
  * @param [out] value monitoring value
