@@ -1,8 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2019 Intel Corporation. All rights reserved.
- * All rights reserved.
+ * Copyright(c) 2018-2021 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -39,11 +38,13 @@
 #include <sys/mount.h>
 #include <errno.h>
 #include <string.h>
+#include <fcntl.h>
 
 #include "pqos.h"
 #include "log.h"
 #include "types.h"
 #include "resctrl.h"
+#include "common.h"
 
 static int resctrl_lock_fd = -1; /**< File descriptor to the lockfile */
 
@@ -156,23 +157,23 @@ resctrl_mount(const enum pqos_cdp_config l3_cdp_cfg,
 
         /* l3 cdp mount option */
         if (l3_cdp_cfg == PQOS_REQUIRE_CDP_ON) {
-                strcat(buf, "cdp");
+                pqos_strcat(buf, "cdp", sizeof(buf));
                 options = buf;
         }
 
         /* l2 cdp mount option */
         if (l2_cdp_cfg == PQOS_REQUIRE_CDP_ON) {
                 if (options != NULL)
-                        strcat(buf, ",");
-                strcat(buf, "cdpl2");
+                        pqos_strcat(buf, ",", sizeof(buf));
+                pqos_strcat(buf, "cdpl2", sizeof(buf));
                 options = buf;
         }
 
         /* mba mount option */
         if (mba_cfg == PQOS_MBA_CTRL) {
                 if (options != NULL)
-                        strcat(buf, ",");
-                strcat(buf, "mba_MBps");
+                        pqos_strcat(buf, ",", sizeof(buf));
+                pqos_strcat(buf, "mba_MBps", sizeof(buf));
                 options = buf;
         }
 
@@ -210,6 +211,17 @@ resctrl_cpumask_set(const unsigned lcore, struct resctrl_cpumask *mask)
         mask->tab[item] = mask->tab[item] | (1 << bit);
 }
 
+void
+resctrl_cpumask_unset(const unsigned lcore, struct resctrl_cpumask *mask)
+{
+        /* index in mask table */
+        const unsigned item = (sizeof(mask->tab) - 1) - (lcore / CHAR_BIT);
+        const unsigned bit = lcore % CHAR_BIT;
+
+        /* Clear lcore bit in mask table item */
+        mask->tab[item] &= ~(1 << bit);
+}
+
 int
 resctrl_cpumask_get(const unsigned lcore, const struct resctrl_cpumask *mask)
 {
@@ -225,6 +237,7 @@ int
 resctrl_cpumask_write(FILE *fd, const struct resctrl_cpumask *mask)
 {
         unsigned i;
+        unsigned found_nonzero = 0;
 
         ASSERT(fd != NULL);
         ASSERT(mask != NULL);
@@ -232,6 +245,11 @@ resctrl_cpumask_write(FILE *fd, const struct resctrl_cpumask *mask)
         for (i = 0; i < sizeof(mask->tab); i++) {
                 const unsigned value = (unsigned)mask->tab[i];
 
+                /* skip leading 0 */
+                if (!found_nonzero && value == 0x0)
+                        continue;
+                found_nonzero = 1;
+
                 if (fprintf(fd, "%02x", value) < 0) {
                         LOG_ERROR("Failed to write cpu mask\n");
                         break;
@@ -242,6 +260,8 @@ resctrl_cpumask_write(FILE *fd, const struct resctrl_cpumask *mask)
                                 break;
                         }
         }
+        if (!found_nonzero)
+                fprintf(fd, "0");
 
         /* check if error occurred in loop */
         if (i < sizeof(mask->tab))
