@@ -1,8 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017-2019 Intel Corporation. All rights reserved.
- * All rights reserved.
+ * Copyright(c) 2017-2021 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -47,10 +46,9 @@
 #include "main.h"
 #include "cap.h"
 
-#define BUFFER_SIZE 256
+#define BUFFER_SIZE 512
 #define NON_VERBOSE 0
 
-
 /**
  * @brief Print line with indentation
  *
@@ -166,33 +164,41 @@ cap_print_features_mon(const unsigned indent,
                 if (buffer == NULL)
                         continue;
 
-                if (verbose &&
-                        (monitor->scale_factor != 0 || monitor->max_rmid != 0))
-                        snprintf(buffer + strlen(buffer),
-                                 BUFFER_SIZE - strlen(buffer),
-                                 "%*s%s: scale factor %u, max_rmid %u\n",
-                                 indent + 8, "",
-                                 get_mon_event_name(monitor->type),
-                                 monitor->scale_factor, monitor->max_rmid);
-                else
-                        snprintf(buffer + strlen(buffer),
-                                 BUFFER_SIZE - strlen(buffer),
-                                 "%*s%s\n",
-                                 indent + 8, "",
-                                 get_mon_event_name(monitor->type));
+                snprintf(buffer + strlen(buffer), BUFFER_SIZE - strlen(buffer),
+                         "%*s%s\n", indent + 8, "",
+                         get_mon_event_name(monitor->type));
+
+                if (verbose) {
+                        if (monitor->scale_factor != 0)
+                                snprintf(buffer + strlen(buffer),
+                                         BUFFER_SIZE - strlen(buffer),
+                                         "%*s scale factor: %u\n", indent + 12,
+                                         "", monitor->scale_factor);
+                        if (monitor->max_rmid != 0)
+                                snprintf(buffer + strlen(buffer),
+                                         BUFFER_SIZE - strlen(buffer),
+                                         "%*s max rmid: %u\n", indent + 12, "",
+                                         monitor->max_rmid);
+                        if (monitor->counter_length != 0)
+                                snprintf(buffer + strlen(buffer),
+                                         BUFFER_SIZE - strlen(buffer),
+                                         "%*s counter length: %ub\n",
+                                         indent + 12, "",
+                                         monitor->counter_length);
+                }
         }
 
         printf_indent(indent, "Monitoring\n");
 
         if (strlen(buffer_cache) > 0) {
                 printf_indent(indent + 4,
-                        "Cache Monitoring Technology (CMT) events:\n");
+                              "Cache Monitoring Technology (CMT) events:\n");
                 printf("%s", buffer_cache);
         }
 
         if (strlen(buffer_memory) > 0) {
                 printf_indent(indent + 4,
-                        "Memory Bandwidth Monitoring (MBM) events:\n");
+                              "Memory Bandwidth Monitoring (MBM) events:\n");
                 printf("%s", buffer_memory);
         }
 
@@ -220,8 +226,8 @@ cap_print_features_l3ca(const unsigned indent,
 
         printf_indent(indent, "L3 CAT\n");
         printf_indent(indent + 4, "CDP: %s\n",
-                l3ca->cdp ? (l3ca->cdp_on ? "enabled" : "disabled") :
-                "unsupported");
+                      l3ca->cdp ? (l3ca->cdp_on ? "enabled" : "disabled")
+                                : "unsupported");
         printf_indent(indent + 4, "Num COS: %u\n", l3ca->num_classes);
 
         if (!verbose)
@@ -229,7 +235,7 @@ cap_print_features_l3ca(const unsigned indent,
 
         printf_indent(indent + 4, "Way size: %u bytes\n", l3ca->way_size);
         printf_indent(indent + 4, "Ways contention bit-mask: 0x%lx\n",
-                l3ca->way_contention);
+                      l3ca->way_contention);
         if (pqos_l3ca_get_min_cbm_bits(&min_cbm_bits) != PQOS_RETVAL_OK)
                 printf_indent(indent + 4, "Min CBM bits: unavailable\n");
         else
@@ -256,8 +262,8 @@ cap_print_features_l2ca(const unsigned indent,
 
         printf_indent(indent, "L2 CAT\n");
         printf_indent(indent + 4, "CDP: %s\n",
-                l2ca->cdp ? (l2ca->cdp_on ? "enabled" : "disabled") :
-                "unsupported");
+                      l2ca->cdp ? (l2ca->cdp_on ? "enabled" : "disabled")
+                                : "unsupported");
         printf_indent(indent + 4, "Num COS: %u\n", l2ca->num_classes);
 
         if (!verbose)
@@ -265,7 +271,7 @@ cap_print_features_l2ca(const unsigned indent,
 
         printf_indent(indent + 4, "Way size: %u bytes\n", l2ca->way_size);
         printf_indent(indent + 4, "Ways contention bit-mask: 0x%lx\n",
-                l2ca->way_contention);
+                      l2ca->way_contention);
         if (pqos_l2ca_get_min_cbm_bits(&min_cbm_bits) != PQOS_RETVAL_OK)
                 printf_indent(indent + 4, "Min CBM bits: unavailable\n");
         else
@@ -273,7 +279,6 @@ cap_print_features_l2ca(const unsigned indent,
         printf_indent(indent + 4, "Max CBM bits: %u\n", l2ca->num_ways);
 }
 
-
 /**
  * @brief Print MBA capabilities
  *
@@ -311,138 +316,9 @@ cap_print_features_mba(const unsigned indent,
         printf_indent(indent + 4, "Granularity: %u\n", mba->throttle_step);
         printf_indent(indent + 4, "Min B/W: %u\n", 100 - mba->throttle_max);
         printf_indent(indent + 4, "Type: %s\n",
-                mba->is_linear ? "linear" : "nonlinear");
+                      mba->is_linear ? "linear" : "nonlinear");
 }
 
-/**
- * @brief Print HW capabilities
- *
- * @param [in] cap_mon monitoring capability structure
- * @param [in] cap_l3ca L3 CAT capability structures
- * @param [in] cap_l2ca L2 CAT capability structures
- * @param [in] cap_mba MBA capability structures
- * @param [in] verbose verbose mode
- */
-static void
-cap_print_features_hw(const struct pqos_capability *cap_mon,
-                      const struct pqos_capability *cap_l3ca,
-                      const struct pqos_capability *cap_l2ca,
-                      const struct pqos_capability *cap_mba,
-                      const int verbose)
-{
-        if (cap_mon == NULL && cap_l3ca == NULL &&
-            cap_l2ca == NULL && cap_mba == NULL)
-                return;
-
-        /**
-         * Print out supported capabilities information
-         */
-        printf("Hardware capabilities\n");
-
-        /**
-         * Monitoring capabilities
-         */
-        if (cap_mon != NULL)
-                cap_print_features_mon(4, cap_mon->u.mon, verbose);
-
-        if (cap_l3ca != NULL || cap_l2ca != NULL || cap_mba != NULL)
-                printf_indent(4, "Allocation\n");
-
-        /**
-         * Cache Allocation capabilities
-         */
-        if (cap_l3ca != NULL || cap_l2ca != NULL)
-                printf_indent(8, "Cache Allocation Technology (CAT)\n");
-
-        if (cap_l3ca != NULL)
-                cap_print_features_l3ca(12, cap_l3ca->u.l3ca, verbose);
-
-        if (cap_l2ca != NULL)
-                cap_print_features_l2ca(12, cap_l2ca->u.l2ca, verbose);
-
-        /**
-         * Memory Bandwidth Allocation capabilities
-         */
-        if (cap_mba != NULL)
-                cap_print_features_mba(8, cap_mba->u.mba, verbose);
-}
-
-#ifdef __linux__
-/**
- * @brief Print OS capabilities
- *
- * @param [in] cap_mon monitoring capability structure
- * @param [in] cap_l3ca L3 CAT capability structures
- * @param [in] cap_l2ca L2 CAT capability structures
- * @param [in] cap_mba MBA capability structures
- * @param [in] verbose verbose mode
- */
-static void
-cap_print_features_os(const struct pqos_capability *cap_mon,
-                      const struct pqos_capability *cap_l3ca,
-                      const struct pqos_capability *cap_l2ca,
-                      const struct pqos_capability *cap_mba,
-                      const int verbose)
-{
-        unsigned min_num_cos = 0;
-        struct utsname name;
-
-        /**
-         * Get min. number of COS
-         */
-        if (cap_l3ca != NULL)
-                min_num_cos = cap_l3ca->u.l3ca->num_classes;
-
-        if (cap_l2ca != NULL)
-                if (min_num_cos == 0 ||
-                    min_num_cos > cap_l2ca->u.l2ca->num_classes)
-                        min_num_cos = cap_l2ca->u.l2ca->num_classes;
-
-        if (cap_mba != NULL)
-                if (min_num_cos == 0 ||
-                    min_num_cos > cap_mba->u.mba->num_classes)
-                        min_num_cos = cap_mba->u.mba->num_classes;
-
-        printf("OS capabilities");
-        if (uname(&name) >= 0)
-                printf(" (%s kernel %s)", name.sysname, name.release);
-        printf("\n");
-
-        if (cap_mon != NULL)
-                cap_print_features_mon(4, cap_mon->u.mon, verbose);
-
-        if (cap_l3ca != NULL || cap_l2ca != NULL || cap_mba != NULL)
-                printf_indent(4, "Allocation\n");
-
-        if (cap_l3ca != NULL || cap_l2ca != NULL)
-                printf_indent(8, "Cache Allocation Technology (CAT)\n");
-
-        if (cap_l3ca != NULL) {
-                struct pqos_cap_l3ca l3ca = *cap_l3ca->u.l3ca;
-
-                l3ca.num_classes = min_num_cos;
-
-                cap_print_features_l3ca(12, &l3ca, verbose);
-        }
-
-        if (cap_l2ca != NULL) {
-                struct pqos_cap_l2ca l2ca = *cap_l2ca->u.l2ca;
-
-                l2ca.num_classes = min_num_cos;
-
-                cap_print_features_l2ca(12, &l2ca, verbose);
-        }
-
-        if (cap_mba != NULL) {
-                struct pqos_cap_mba mba = *cap_mba->u.mba;
-
-                mba.num_classes = min_num_cos;
-
-                cap_print_features_mba(8, &mba, verbose);
-        }
-}
-#endif
-
 /**
  * @brief Print capabilities
  *
@@ -482,15 +358,51 @@ cap_print_features(const struct pqos_cap *cap,
                         break;
                 }
 
+        if (cap_mon == NULL && cap_l3ca == NULL && cap_l2ca == NULL &&
+            cap_mba == NULL)
+                return;
+
         if (sel_interface == PQOS_INTER_MSR)
-                cap_print_features_hw(cap_mon, cap_l3ca, cap_l2ca, cap_mba,
-                                      verbose);
+                printf("Hardware capabilities\n");
+
 #ifdef __linux__
-        else
-                cap_print_features_os(cap_mon, cap_l3ca, cap_l2ca, cap_mba,
-                                      verbose);
+        else {
+                struct utsname name;
+
+                printf("OS capabilities");
+                if (uname(&name) >= 0)
+                        printf(" (%s kernel %s)", name.sysname, name.release);
+                printf("\n");
+        }
 #endif
 
+        /**
+         * Monitoring capabilities
+         */
+        if (cap_mon != NULL)
+                cap_print_features_mon(4, cap_mon->u.mon, verbose);
+
+        if (cap_l3ca != NULL || cap_l2ca != NULL || cap_mba != NULL)
+                printf_indent(4, "Allocation\n");
+
+        /**
+         * Cache Allocation capabilities
+         */
+        if (cap_l3ca != NULL || cap_l2ca != NULL)
+                printf_indent(8, "Cache Allocation Technology (CAT)\n");
+
+        if (cap_l3ca != NULL)
+                cap_print_features_l3ca(12, cap_l3ca->u.l3ca, verbose);
+
+        if (cap_l2ca != NULL)
+                cap_print_features_l2ca(12, cap_l2ca->u.l2ca, verbose);
+
+        /**
+         * Memory Bandwidth Allocation capabilities
+         */
+        if (cap_mba != NULL)
+                cap_print_features_mba(8, cap_mba->u.mba, verbose);
+
         if (!verbose)
                 return;
 
