@@ -1,8 +1,7 @@
 /*
  *   BSD LICENSE
  *
- *   Copyright(c) 2016-2019 Intel Corporation. All rights reserved.
- *   All rights reserved.
+ *   Copyright(c) 2016-2021 Intel Corporation. All rights reserved.
  *
  *   Redistribution and use in source and binary forms, with or without
  *   modification, are permitted provided that the following conditions
@@ -56,6 +55,8 @@ static pid_t child = -1;
  *
  * @status exit status
  */
+static void _exit_flush(int status) __attribute__((noreturn));
+
 static void
 _exit_flush(int status)
 {
@@ -420,16 +421,16 @@ parse_args(int argc, char **argv)
 
         static const struct option lgopts[] = {
             /* clang-format off */
-		{ "cpu",	required_argument,	0, 'c' },
-		{ "pid",	required_argument,	0, 'p' },
-		{ "reset",	required_argument,	0, 'r' },
-		{ "rdt",	required_argument,	0, 't' },
-		{ "sudokeep",	no_argument,		0, 'k' },
-		{ "verbose",	no_argument,		0, 'v' },
-		{ "iface-os",   no_argument,            0, 'I' },
-		{ "help",	no_argument,		0, 'h' },
-		{ "version",	no_argument,		0, 'w' },
-		{ NULL, 0, 0, 0 }
+                { "cpu",        required_argument,      0, 'c' },
+                { "pid",        required_argument,      0, 'p' },
+                { "reset",      required_argument,      0, 'r' },
+                { "rdt",        required_argument,      0, 't' },
+                { "sudokeep",   no_argument,            0, 'k' },
+                { "verbose",    no_argument,            0, 'v' },
+                { "iface-os",   no_argument,            0, 'I' },
+                { "help",       no_argument,            0, 'h' },
+                { "version",    no_argument,            0, 'w' },
+                { NULL, 0, 0, 0 }
             /* clang-format on */
         };
 
@@ -723,6 +724,4 @@ main(int argc, char **argv)
                 rdtset_fini();
                 _exit_flush(EXIT_SUCCESS);
         }
-
-        exit(EXIT_FAILURE);
 }
